# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDomainsMyDeviceResult',
    'AwaitableGetDomainsMyDeviceResult',
    'get_domains_my_device',
    'get_domains_my_device_output',
]

@pulumi.output_type
class GetDomainsMyDeviceResult:
    """
    A collection of values returned by getDomainsMyDevice.
    """
    def __init__(__self__, additional_attributes=None, app_version=None, attribute_sets=None, attributes=None, authentication_factors=None, authentication_method=None, authorization=None, base_public_key=None, compartment_ocid=None, country_code=None, delete_in_progress=None, device_type=None, device_uuid=None, display_name=None, domain_ocid=None, expires_on=None, external_id=None, id=None, idcs_created_bies=None, idcs_endpoint=None, idcs_last_modified_bies=None, idcs_last_upgraded_in_release=None, idcs_prevented_operations=None, is_acc_rec_enabled=None, is_compliant=None, last_sync_time=None, last_validated_time=None, metas=None, my_device_id=None, non_compliances=None, ocid=None, package_id=None, phone_number=None, platform=None, push_notification_targets=None, reason=None, resource_type_schema_version=None, schemas=None, seed=None, seed_dek_id=None, status=None, tags=None, tenancy_ocid=None, third_party_factors=None, users=None):
        if additional_attributes and not isinstance(additional_attributes, list):
            raise TypeError("Expected argument 'additional_attributes' to be a list")
        pulumi.set(__self__, "additional_attributes", additional_attributes)
        if app_version and not isinstance(app_version, str):
            raise TypeError("Expected argument 'app_version' to be a str")
        pulumi.set(__self__, "app_version", app_version)
        if attribute_sets and not isinstance(attribute_sets, list):
            raise TypeError("Expected argument 'attribute_sets' to be a list")
        pulumi.set(__self__, "attribute_sets", attribute_sets)
        if attributes and not isinstance(attributes, str):
            raise TypeError("Expected argument 'attributes' to be a str")
        pulumi.set(__self__, "attributes", attributes)
        if authentication_factors and not isinstance(authentication_factors, list):
            raise TypeError("Expected argument 'authentication_factors' to be a list")
        pulumi.set(__self__, "authentication_factors", authentication_factors)
        if authentication_method and not isinstance(authentication_method, str):
            raise TypeError("Expected argument 'authentication_method' to be a str")
        pulumi.set(__self__, "authentication_method", authentication_method)
        if authorization and not isinstance(authorization, str):
            raise TypeError("Expected argument 'authorization' to be a str")
        pulumi.set(__self__, "authorization", authorization)
        if base_public_key and not isinstance(base_public_key, str):
            raise TypeError("Expected argument 'base_public_key' to be a str")
        pulumi.set(__self__, "base_public_key", base_public_key)
        if compartment_ocid and not isinstance(compartment_ocid, str):
            raise TypeError("Expected argument 'compartment_ocid' to be a str")
        pulumi.set(__self__, "compartment_ocid", compartment_ocid)
        if country_code and not isinstance(country_code, str):
            raise TypeError("Expected argument 'country_code' to be a str")
        pulumi.set(__self__, "country_code", country_code)
        if delete_in_progress and not isinstance(delete_in_progress, bool):
            raise TypeError("Expected argument 'delete_in_progress' to be a bool")
        pulumi.set(__self__, "delete_in_progress", delete_in_progress)
        if device_type and not isinstance(device_type, str):
            raise TypeError("Expected argument 'device_type' to be a str")
        pulumi.set(__self__, "device_type", device_type)
        if device_uuid and not isinstance(device_uuid, str):
            raise TypeError("Expected argument 'device_uuid' to be a str")
        pulumi.set(__self__, "device_uuid", device_uuid)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if domain_ocid and not isinstance(domain_ocid, str):
            raise TypeError("Expected argument 'domain_ocid' to be a str")
        pulumi.set(__self__, "domain_ocid", domain_ocid)
        if expires_on and not isinstance(expires_on, int):
            raise TypeError("Expected argument 'expires_on' to be a int")
        pulumi.set(__self__, "expires_on", expires_on)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if idcs_created_bies and not isinstance(idcs_created_bies, list):
            raise TypeError("Expected argument 'idcs_created_bies' to be a list")
        pulumi.set(__self__, "idcs_created_bies", idcs_created_bies)
        if idcs_endpoint and not isinstance(idcs_endpoint, str):
            raise TypeError("Expected argument 'idcs_endpoint' to be a str")
        pulumi.set(__self__, "idcs_endpoint", idcs_endpoint)
        if idcs_last_modified_bies and not isinstance(idcs_last_modified_bies, list):
            raise TypeError("Expected argument 'idcs_last_modified_bies' to be a list")
        pulumi.set(__self__, "idcs_last_modified_bies", idcs_last_modified_bies)
        if idcs_last_upgraded_in_release and not isinstance(idcs_last_upgraded_in_release, str):
            raise TypeError("Expected argument 'idcs_last_upgraded_in_release' to be a str")
        pulumi.set(__self__, "idcs_last_upgraded_in_release", idcs_last_upgraded_in_release)
        if idcs_prevented_operations and not isinstance(idcs_prevented_operations, list):
            raise TypeError("Expected argument 'idcs_prevented_operations' to be a list")
        pulumi.set(__self__, "idcs_prevented_operations", idcs_prevented_operations)
        if is_acc_rec_enabled and not isinstance(is_acc_rec_enabled, bool):
            raise TypeError("Expected argument 'is_acc_rec_enabled' to be a bool")
        pulumi.set(__self__, "is_acc_rec_enabled", is_acc_rec_enabled)
        if is_compliant and not isinstance(is_compliant, bool):
            raise TypeError("Expected argument 'is_compliant' to be a bool")
        pulumi.set(__self__, "is_compliant", is_compliant)
        if last_sync_time and not isinstance(last_sync_time, str):
            raise TypeError("Expected argument 'last_sync_time' to be a str")
        pulumi.set(__self__, "last_sync_time", last_sync_time)
        if last_validated_time and not isinstance(last_validated_time, str):
            raise TypeError("Expected argument 'last_validated_time' to be a str")
        pulumi.set(__self__, "last_validated_time", last_validated_time)
        if metas and not isinstance(metas, list):
            raise TypeError("Expected argument 'metas' to be a list")
        pulumi.set(__self__, "metas", metas)
        if my_device_id and not isinstance(my_device_id, str):
            raise TypeError("Expected argument 'my_device_id' to be a str")
        pulumi.set(__self__, "my_device_id", my_device_id)
        if non_compliances and not isinstance(non_compliances, list):
            raise TypeError("Expected argument 'non_compliances' to be a list")
        pulumi.set(__self__, "non_compliances", non_compliances)
        if ocid and not isinstance(ocid, str):
            raise TypeError("Expected argument 'ocid' to be a str")
        pulumi.set(__self__, "ocid", ocid)
        if package_id and not isinstance(package_id, str):
            raise TypeError("Expected argument 'package_id' to be a str")
        pulumi.set(__self__, "package_id", package_id)
        if phone_number and not isinstance(phone_number, str):
            raise TypeError("Expected argument 'phone_number' to be a str")
        pulumi.set(__self__, "phone_number", phone_number)
        if platform and not isinstance(platform, str):
            raise TypeError("Expected argument 'platform' to be a str")
        pulumi.set(__self__, "platform", platform)
        if push_notification_targets and not isinstance(push_notification_targets, list):
            raise TypeError("Expected argument 'push_notification_targets' to be a list")
        pulumi.set(__self__, "push_notification_targets", push_notification_targets)
        if reason and not isinstance(reason, str):
            raise TypeError("Expected argument 'reason' to be a str")
        pulumi.set(__self__, "reason", reason)
        if resource_type_schema_version and not isinstance(resource_type_schema_version, str):
            raise TypeError("Expected argument 'resource_type_schema_version' to be a str")
        pulumi.set(__self__, "resource_type_schema_version", resource_type_schema_version)
        if schemas and not isinstance(schemas, list):
            raise TypeError("Expected argument 'schemas' to be a list")
        pulumi.set(__self__, "schemas", schemas)
        if seed and not isinstance(seed, str):
            raise TypeError("Expected argument 'seed' to be a str")
        pulumi.set(__self__, "seed", seed)
        if seed_dek_id and not isinstance(seed_dek_id, str):
            raise TypeError("Expected argument 'seed_dek_id' to be a str")
        pulumi.set(__self__, "seed_dek_id", seed_dek_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tenancy_ocid and not isinstance(tenancy_ocid, str):
            raise TypeError("Expected argument 'tenancy_ocid' to be a str")
        pulumi.set(__self__, "tenancy_ocid", tenancy_ocid)
        if third_party_factors and not isinstance(third_party_factors, list):
            raise TypeError("Expected argument 'third_party_factors' to be a list")
        pulumi.set(__self__, "third_party_factors", third_party_factors)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="additionalAttributes")
    def additional_attributes(self) -> Sequence['outputs.GetDomainsMyDeviceAdditionalAttributeResult']:
        """
        Device additional attributes
        """
        return pulumi.get(self, "additional_attributes")

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> str:
        """
        Mobile Authenticator App Version
        """
        return pulumi.get(self, "app_version")

    @property
    @pulumi.getter(name="attributeSets")
    def attribute_sets(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "attribute_sets")

    @property
    @pulumi.getter
    def attributes(self) -> Optional[str]:
        return pulumi.get(self, "attributes")

    @property
    @pulumi.getter(name="authenticationFactors")
    def authentication_factors(self) -> Sequence['outputs.GetDomainsMyDeviceAuthenticationFactorResult']:
        """
        Authentication Factors
        """
        return pulumi.get(self, "authentication_factors")

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> str:
        """
        Authentication method used in device. For FIDO, it will contain SECURITY_KEY/WINDOWS_HELLO etc
        """
        return pulumi.get(self, "authentication_method")

    @property
    @pulumi.getter
    def authorization(self) -> Optional[str]:
        return pulumi.get(self, "authorization")

    @property
    @pulumi.getter(name="basePublicKey")
    def base_public_key(self) -> str:
        """
        Device base public Key
        """
        return pulumi.get(self, "base_public_key")

    @property
    @pulumi.getter(name="compartmentOcid")
    def compartment_ocid(self) -> str:
        """
        Oracle Cloud Infrastructure Compartment Id (ocid) in which the resource lives.
        """
        return pulumi.get(self, "compartment_ocid")

    @property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> str:
        """
        Country code of user's Phone Number
        """
        return pulumi.get(self, "country_code")

    @property
    @pulumi.getter(name="deleteInProgress")
    def delete_in_progress(self) -> bool:
        """
        A boolean flag indicating this resource in the process of being deleted. Usually set to true when synchronous deletion of the resource would take too long.
        """
        return pulumi.get(self, "delete_in_progress")

    @property
    @pulumi.getter(name="deviceType")
    def device_type(self) -> str:
        """
        Device hardware name/model
        """
        return pulumi.get(self, "device_type")

    @property
    @pulumi.getter(name="deviceUuid")
    def device_uuid(self) -> str:
        """
        Unique id sent from device
        """
        return pulumi.get(self, "device_uuid")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Device friendly display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="domainOcid")
    def domain_ocid(self) -> str:
        """
        Oracle Cloud Infrastructure Domain Id (ocid) in which the resource lives.
        """
        return pulumi.get(self, "domain_ocid")

    @property
    @pulumi.getter(name="expiresOn")
    def expires_on(self) -> int:
        """
        Attribute added for replication log, it is not used by IDCS, just added as place holder
        """
        return pulumi.get(self, "expires_on")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        An identifier for the Resource as defined by the Service Consumer. The externalId may simplify identification of the Resource between Service Consumer and Service Provider by allowing the Consumer to refer to the Resource with its own identifier, obviating the need to store a local mapping between the local identifier of the Resource and the identifier used by the Service Provider. Each Resource MAY include a non-empty externalId value. The value of the externalId attribute is always issued be the Service Consumer and can never be specified by the Service Provider. The Service Provider MUST always interpret the externalId as scoped to the Service Consumer's tenant.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idcsCreatedBies")
    def idcs_created_bies(self) -> Sequence['outputs.GetDomainsMyDeviceIdcsCreatedByResult']:
        """
        The User or App who created the Resource
        """
        return pulumi.get(self, "idcs_created_bies")

    @property
    @pulumi.getter(name="idcsEndpoint")
    def idcs_endpoint(self) -> str:
        return pulumi.get(self, "idcs_endpoint")

    @property
    @pulumi.getter(name="idcsLastModifiedBies")
    def idcs_last_modified_bies(self) -> Sequence['outputs.GetDomainsMyDeviceIdcsLastModifiedByResult']:
        """
        The User or App who modified the Resource
        """
        return pulumi.get(self, "idcs_last_modified_bies")

    @property
    @pulumi.getter(name="idcsLastUpgradedInRelease")
    def idcs_last_upgraded_in_release(self) -> str:
        """
        The release number when the resource was upgraded.
        """
        return pulumi.get(self, "idcs_last_upgraded_in_release")

    @property
    @pulumi.getter(name="idcsPreventedOperations")
    def idcs_prevented_operations(self) -> Sequence[str]:
        """
        Each value of this attribute specifies an operation that only an internal client may perform on this particular resource.
        """
        return pulumi.get(self, "idcs_prevented_operations")

    @property
    @pulumi.getter(name="isAccRecEnabled")
    def is_acc_rec_enabled(self) -> bool:
        """
        Flag that indicates whether the device is enrolled for account recovery
        """
        return pulumi.get(self, "is_acc_rec_enabled")

    @property
    @pulumi.getter(name="isCompliant")
    def is_compliant(self) -> bool:
        """
        Device Compliance Status
        """
        return pulumi.get(self, "is_compliant")

    @property
    @pulumi.getter(name="lastSyncTime")
    def last_sync_time(self) -> str:
        """
        Last Sync time for device
        """
        return pulumi.get(self, "last_sync_time")

    @property
    @pulumi.getter(name="lastValidatedTime")
    def last_validated_time(self) -> str:
        """
        The most recent timestamp when the device was successfully validated using one time passcode
        """
        return pulumi.get(self, "last_validated_time")

    @property
    @pulumi.getter
    def metas(self) -> Sequence['outputs.GetDomainsMyDeviceMetaResult']:
        """
        A complex attribute that contains resource metadata. All sub-attributes are OPTIONAL.
        """
        return pulumi.get(self, "metas")

    @property
    @pulumi.getter(name="myDeviceId")
    def my_device_id(self) -> str:
        return pulumi.get(self, "my_device_id")

    @property
    @pulumi.getter(name="nonCompliances")
    def non_compliances(self) -> Sequence['outputs.GetDomainsMyDeviceNonComplianceResult']:
        """
        Device Non Compliances
        """
        return pulumi.get(self, "non_compliances")

    @property
    @pulumi.getter
    def ocid(self) -> str:
        """
        The OCID of the user
        """
        return pulumi.get(self, "ocid")

    @property
    @pulumi.getter(name="packageId")
    def package_id(self) -> str:
        """
        Mobile Authenticator App Package Id
        """
        return pulumi.get(self, "package_id")

    @property
    @pulumi.getter(name="phoneNumber")
    def phone_number(self) -> str:
        """
        User's Phone Number
        """
        return pulumi.get(self, "phone_number")

    @property
    @pulumi.getter
    def platform(self) -> str:
        """
        Device Platform
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="pushNotificationTargets")
    def push_notification_targets(self) -> Sequence['outputs.GetDomainsMyDevicePushNotificationTargetResult']:
        """
        Push Notification target. Reference to Device notification related resource
        """
        return pulumi.get(self, "push_notification_targets")

    @property
    @pulumi.getter
    def reason(self) -> str:
        """
        Additional comments/reasons for the change in device status
        """
        return pulumi.get(self, "reason")

    @property
    @pulumi.getter(name="resourceTypeSchemaVersion")
    def resource_type_schema_version(self) -> Optional[str]:
        return pulumi.get(self, "resource_type_schema_version")

    @property
    @pulumi.getter
    def schemas(self) -> Sequence[str]:
        """
        REQUIRED. The schemas attribute is an array of Strings which allows introspection of the supported schema version for a SCIM representation as well any schema extensions supported by that representation. Each String value must be a unique URI. This specification defines URIs for User, Group, and a standard \\"enterprise\\" extension. All representations of SCIM schema MUST include a non-zero value array with value(s) of the URIs supported by that representation. Duplicate values MUST NOT be included. Value order is not specified and MUST not impact behavior.
        """
        return pulumi.get(self, "schemas")

    @property
    @pulumi.getter
    def seed(self) -> str:
        """
        Attribute added for replication log, it is not used by IDCS, it is actual encrypted TOTP seed for the user
        """
        return pulumi.get(self, "seed")

    @property
    @pulumi.getter(name="seedDekId")
    def seed_dek_id(self) -> str:
        """
        Attribute added for replication log, it is not used by IDCS, the DEK that encrypts the specific seed for that user
        """
        return pulumi.get(self, "seed_dek_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Device Status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetDomainsMyDeviceTagResult']:
        """
        A list of tags on this resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenancyOcid")
    def tenancy_ocid(self) -> str:
        """
        Oracle Cloud Infrastructure Tenant Id (ocid) in which the resource lives.
        """
        return pulumi.get(self, "tenancy_ocid")

    @property
    @pulumi.getter(name="thirdPartyFactors")
    def third_party_factors(self) -> Sequence['outputs.GetDomainsMyDeviceThirdPartyFactorResult']:
        """
        User's third-party authentication factor details
        """
        return pulumi.get(self, "third_party_factors")

    @property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetDomainsMyDeviceUserResult']:
        """
        Device member
        """
        return pulumi.get(self, "users")


class AwaitableGetDomainsMyDeviceResult(GetDomainsMyDeviceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainsMyDeviceResult(
            additional_attributes=self.additional_attributes,
            app_version=self.app_version,
            attribute_sets=self.attribute_sets,
            attributes=self.attributes,
            authentication_factors=self.authentication_factors,
            authentication_method=self.authentication_method,
            authorization=self.authorization,
            base_public_key=self.base_public_key,
            compartment_ocid=self.compartment_ocid,
            country_code=self.country_code,
            delete_in_progress=self.delete_in_progress,
            device_type=self.device_type,
            device_uuid=self.device_uuid,
            display_name=self.display_name,
            domain_ocid=self.domain_ocid,
            expires_on=self.expires_on,
            external_id=self.external_id,
            id=self.id,
            idcs_created_bies=self.idcs_created_bies,
            idcs_endpoint=self.idcs_endpoint,
            idcs_last_modified_bies=self.idcs_last_modified_bies,
            idcs_last_upgraded_in_release=self.idcs_last_upgraded_in_release,
            idcs_prevented_operations=self.idcs_prevented_operations,
            is_acc_rec_enabled=self.is_acc_rec_enabled,
            is_compliant=self.is_compliant,
            last_sync_time=self.last_sync_time,
            last_validated_time=self.last_validated_time,
            metas=self.metas,
            my_device_id=self.my_device_id,
            non_compliances=self.non_compliances,
            ocid=self.ocid,
            package_id=self.package_id,
            phone_number=self.phone_number,
            platform=self.platform,
            push_notification_targets=self.push_notification_targets,
            reason=self.reason,
            resource_type_schema_version=self.resource_type_schema_version,
            schemas=self.schemas,
            seed=self.seed,
            seed_dek_id=self.seed_dek_id,
            status=self.status,
            tags=self.tags,
            tenancy_ocid=self.tenancy_ocid,
            third_party_factors=self.third_party_factors,
            users=self.users)


def get_domains_my_device(attribute_sets: Optional[Sequence[str]] = None,
                          attributes: Optional[str] = None,
                          authorization: Optional[str] = None,
                          idcs_endpoint: Optional[str] = None,
                          my_device_id: Optional[str] = None,
                          resource_type_schema_version: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainsMyDeviceResult:
    """
    This data source provides details about a specific My Device resource in Oracle Cloud Infrastructure Identity Domains service.

    Get a Device

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_my_device = oci.Identity.get_domains_my_device(idcs_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        my_device_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        attribute_sets=[],
        attributes="",
        authorization=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_type_schema_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] attribute_sets: A multi-valued list of strings indicating the return type of attribute definition. The specified set of attributes can be fetched by the return type of the attribute. One or more values can be given together to fetch more than one group of attributes. If 'attributes' query parameter is also available, union of the two is fetched. Valid values - all, always, never, request, default. Values are case-insensitive.
    :param str attributes: A comma-delimited string that specifies the names of resource attributes that should be returned in the response. By default, a response that contains resource attributes contains only attributes that are defined in the schema for that resource type as returned=always or returned=default. An attribute that is defined as returned=request is returned in a response only if the request specifies its name in the value of this query parameter. If a request specifies this query parameter, the response contains the attributes that this query parameter specifies, as well as any attribute that is defined as returned=always.
    :param str authorization: The Authorization field value consists of credentials containing the authentication information of the user agent for the realm of the resource being requested.
    :param str idcs_endpoint: The basic endpoint for the identity domain
    :param str my_device_id: ID of the resource
    :param str resource_type_schema_version: An endpoint-specific schema version number to use in the Request. Allowed version values are Earliest Version or Latest Version as specified in each REST API endpoint description, or any sequential number inbetween. All schema attributes/body parameters are a part of version 1. After version 1, any attributes added or deprecated will be tagged with the version that they were added to or deprecated in. If no version is provided, the latest schema version is returned.
    """
    __args__ = dict()
    __args__['attributeSets'] = attribute_sets
    __args__['attributes'] = attributes
    __args__['authorization'] = authorization
    __args__['idcsEndpoint'] = idcs_endpoint
    __args__['myDeviceId'] = my_device_id
    __args__['resourceTypeSchemaVersion'] = resource_type_schema_version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getDomainsMyDevice:getDomainsMyDevice', __args__, opts=opts, typ=GetDomainsMyDeviceResult).value

    return AwaitableGetDomainsMyDeviceResult(
        additional_attributes=__ret__.additional_attributes,
        app_version=__ret__.app_version,
        attribute_sets=__ret__.attribute_sets,
        attributes=__ret__.attributes,
        authentication_factors=__ret__.authentication_factors,
        authentication_method=__ret__.authentication_method,
        authorization=__ret__.authorization,
        base_public_key=__ret__.base_public_key,
        compartment_ocid=__ret__.compartment_ocid,
        country_code=__ret__.country_code,
        delete_in_progress=__ret__.delete_in_progress,
        device_type=__ret__.device_type,
        device_uuid=__ret__.device_uuid,
        display_name=__ret__.display_name,
        domain_ocid=__ret__.domain_ocid,
        expires_on=__ret__.expires_on,
        external_id=__ret__.external_id,
        id=__ret__.id,
        idcs_created_bies=__ret__.idcs_created_bies,
        idcs_endpoint=__ret__.idcs_endpoint,
        idcs_last_modified_bies=__ret__.idcs_last_modified_bies,
        idcs_last_upgraded_in_release=__ret__.idcs_last_upgraded_in_release,
        idcs_prevented_operations=__ret__.idcs_prevented_operations,
        is_acc_rec_enabled=__ret__.is_acc_rec_enabled,
        is_compliant=__ret__.is_compliant,
        last_sync_time=__ret__.last_sync_time,
        last_validated_time=__ret__.last_validated_time,
        metas=__ret__.metas,
        my_device_id=__ret__.my_device_id,
        non_compliances=__ret__.non_compliances,
        ocid=__ret__.ocid,
        package_id=__ret__.package_id,
        phone_number=__ret__.phone_number,
        platform=__ret__.platform,
        push_notification_targets=__ret__.push_notification_targets,
        reason=__ret__.reason,
        resource_type_schema_version=__ret__.resource_type_schema_version,
        schemas=__ret__.schemas,
        seed=__ret__.seed,
        seed_dek_id=__ret__.seed_dek_id,
        status=__ret__.status,
        tags=__ret__.tags,
        tenancy_ocid=__ret__.tenancy_ocid,
        third_party_factors=__ret__.third_party_factors,
        users=__ret__.users)


@_utilities.lift_output_func(get_domains_my_device)
def get_domains_my_device_output(attribute_sets: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 attributes: Optional[pulumi.Input[Optional[str]]] = None,
                                 authorization: Optional[pulumi.Input[Optional[str]]] = None,
                                 idcs_endpoint: Optional[pulumi.Input[str]] = None,
                                 my_device_id: Optional[pulumi.Input[str]] = None,
                                 resource_type_schema_version: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDomainsMyDeviceResult]:
    """
    This data source provides details about a specific My Device resource in Oracle Cloud Infrastructure Identity Domains service.

    Get a Device

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_my_device = oci.Identity.get_domains_my_device(idcs_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        my_device_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        attribute_sets=[],
        attributes="",
        authorization=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_type_schema_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] attribute_sets: A multi-valued list of strings indicating the return type of attribute definition. The specified set of attributes can be fetched by the return type of the attribute. One or more values can be given together to fetch more than one group of attributes. If 'attributes' query parameter is also available, union of the two is fetched. Valid values - all, always, never, request, default. Values are case-insensitive.
    :param str attributes: A comma-delimited string that specifies the names of resource attributes that should be returned in the response. By default, a response that contains resource attributes contains only attributes that are defined in the schema for that resource type as returned=always or returned=default. An attribute that is defined as returned=request is returned in a response only if the request specifies its name in the value of this query parameter. If a request specifies this query parameter, the response contains the attributes that this query parameter specifies, as well as any attribute that is defined as returned=always.
    :param str authorization: The Authorization field value consists of credentials containing the authentication information of the user agent for the realm of the resource being requested.
    :param str idcs_endpoint: The basic endpoint for the identity domain
    :param str my_device_id: ID of the resource
    :param str resource_type_schema_version: An endpoint-specific schema version number to use in the Request. Allowed version values are Earliest Version or Latest Version as specified in each REST API endpoint description, or any sequential number inbetween. All schema attributes/body parameters are a part of version 1. After version 1, any attributes added or deprecated will be tagged with the version that they were added to or deprecated in. If no version is provided, the latest schema version is returned.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetDiscoveryScheduleResult',
    'AwaitableGetDiscoveryScheduleResult',
    'get_discovery_schedule',
    'get_discovery_schedule_output',
]

@pulumi.output_type
class GetDiscoveryScheduleResult:
    """
    A collection of values returned by getDiscoverySchedule.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, discovery_schedule_id=None, display_name=None, execution_recurrences=None, freeform_tags=None, id=None, lifecycle_details=None, state=None, system_tags=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if discovery_schedule_id and not isinstance(discovery_schedule_id, str):
            raise TypeError("Expected argument 'discovery_schedule_id' to be a str")
        pulumi.set(__self__, "discovery_schedule_id", discovery_schedule_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if execution_recurrences and not isinstance(execution_recurrences, str):
            raise TypeError("Expected argument 'execution_recurrences' to be a str")
        pulumi.set(__self__, "execution_recurrences", execution_recurrences)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the discovery schedule exists.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="discoveryScheduleId")
    def discovery_schedule_id(self) -> str:
        return pulumi.get(self, "discovery_schedule_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A user-friendly name for the discovery schedule. Does not have to be unique, and it's mutable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="executionRecurrences")
    def execution_recurrences(self) -> str:
        """
        Recurrence specification for the discovery schedule execution.
        """
        return pulumi.get(self, "execution_recurrences")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the discovery schedule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        The detailed state of the discovery schedule.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        Current state of the discovery schedule.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time when the discovery schedule was created in RFC3339 format.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time when the discovery schedule was last updated in RFC3339 format.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetDiscoveryScheduleResult(GetDiscoveryScheduleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDiscoveryScheduleResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            discovery_schedule_id=self.discovery_schedule_id,
            display_name=self.display_name,
            execution_recurrences=self.execution_recurrences,
            freeform_tags=self.freeform_tags,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            state=self.state,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_discovery_schedule(discovery_schedule_id: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDiscoveryScheduleResult:
    """
    This data source provides details about a specific Discovery Schedule resource in Oracle Cloud Infrastructure Cloud Bridge service.

    Reads information about the specified discovery schedule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_discovery_schedule = oci.CloudBridge.get_discovery_schedule(discovery_schedule_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str discovery_schedule_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the discovery schedule.
    """
    __args__ = dict()
    __args__['discoveryScheduleId'] = discovery_schedule_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:CloudBridge/getDiscoverySchedule:getDiscoverySchedule', __args__, opts=opts, typ=GetDiscoveryScheduleResult).value

    return AwaitableGetDiscoveryScheduleResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        discovery_schedule_id=__ret__.discovery_schedule_id,
        display_name=__ret__.display_name,
        execution_recurrences=__ret__.execution_recurrences,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        lifecycle_details=__ret__.lifecycle_details,
        state=__ret__.state,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_discovery_schedule)
def get_discovery_schedule_output(discovery_schedule_id: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDiscoveryScheduleResult]:
    """
    This data source provides details about a specific Discovery Schedule resource in Oracle Cloud Infrastructure Cloud Bridge service.

    Reads information about the specified discovery schedule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_discovery_schedule = oci.CloudBridge.get_discovery_schedule(discovery_schedule_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str discovery_schedule_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the discovery schedule.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetReportContentResult',
    'AwaitableGetReportContentResult',
    'get_report_content',
    'get_report_content_output',
]

@pulumi.output_type
class GetReportContentResult:
    """
    A collection of values returned by getReportContent.
    """
    def __init__(__self__, id=None, report_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if report_id and not isinstance(report_id, str):
            raise TypeError("Expected argument 'report_id' to be a str")
        pulumi.set(__self__, "report_id", report_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="reportId")
    def report_id(self) -> str:
        return pulumi.get(self, "report_id")


class AwaitableGetReportContentResult(GetReportContentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReportContentResult(
            id=self.id,
            report_id=self.report_id)


def get_report_content(report_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReportContentResult:
    """
    This data source provides details about a specific Report Content resource in Oracle Cloud Infrastructure Data Safe service.

    Downloads the specified report in the form of PDF or XLXS.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_report_content = oci.DataSafe.get_report_content(report_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str report_id: Unique report identifier
    """
    __args__ = dict()
    __args__['reportId'] = report_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getReportContent:getReportContent', __args__, opts=opts, typ=GetReportContentResult).value

    return AwaitableGetReportContentResult(
        id=__ret__.id,
        report_id=__ret__.report_id)


@_utilities.lift_output_func(get_report_content)
def get_report_content_output(report_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetReportContentResult]:
    """
    This data source provides details about a specific Report Content resource in Oracle Cloud Infrastructure Data Safe service.

    Downloads the specified report in the form of PDF or XLXS.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_report_content = oci.DataSafe.get_report_content(report_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str report_id: Unique report identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAuthenticationPolicyResult',
    'AwaitableGetAuthenticationPolicyResult',
    'get_authentication_policy',
    'get_authentication_policy_output',
]

@pulumi.output_type
class GetAuthenticationPolicyResult:
    """
    A collection of values returned by getAuthenticationPolicy.
    """
    def __init__(__self__, compartment_id=None, id=None, network_policies=None, password_policies=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network_policies and not isinstance(network_policies, list):
            raise TypeError("Expected argument 'network_policies' to be a list")
        pulumi.set(__self__, "network_policies", network_policies)
        if password_policies and not isinstance(password_policies, list):
            raise TypeError("Expected argument 'password_policies' to be a list")
        pulumi.set(__self__, "password_policies", password_policies)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment OCID.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="networkPolicies")
    def network_policies(self) -> Sequence['outputs.GetAuthenticationPolicyNetworkPolicyResult']:
        """
        Network policy, Consists of a list of Network Source ids.
        """
        return pulumi.get(self, "network_policies")

    @property
    @pulumi.getter(name="passwordPolicies")
    def password_policies(self) -> Sequence['outputs.GetAuthenticationPolicyPasswordPolicyResult']:
        """
        Password policy, currently set for the given compartment.
        """
        return pulumi.get(self, "password_policies")


class AwaitableGetAuthenticationPolicyResult(GetAuthenticationPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthenticationPolicyResult(
            compartment_id=self.compartment_id,
            id=self.id,
            network_policies=self.network_policies,
            password_policies=self.password_policies)


def get_authentication_policy(compartment_id: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthenticationPolicyResult:
    """
    This data source provides details about a specific Authentication Policy resource in Oracle Cloud Infrastructure Identity service.

    Gets the authentication policy for the given tenancy. You must specify your tenant’s OCID as the value for
    the compartment ID (remember that the tenancy is simply the root compartment).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_authentication_policy = oci.Identity.get_authentication_policy(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getAuthenticationPolicy:getAuthenticationPolicy', __args__, opts=opts, typ=GetAuthenticationPolicyResult).value

    return AwaitableGetAuthenticationPolicyResult(
        compartment_id=__ret__.compartment_id,
        id=__ret__.id,
        network_policies=__ret__.network_policies,
        password_policies=__ret__.password_policies)


@_utilities.lift_output_func(get_authentication_policy)
def get_authentication_policy_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuthenticationPolicyResult]:
    """
    This data source provides details about a specific Authentication Policy resource in Oracle Cloud Infrastructure Identity service.

    Gets the authentication policy for the given tenancy. You must specify your tenant’s OCID as the value for
    the compartment ID (remember that the tenancy is simply the root compartment).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_authentication_policy = oci.Identity.get_authentication_policy(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('oci')


class _ExportableConfig(types.ModuleType):
    @property
    def auth(self) -> Optional[str]:
        """
        (Optional) The type of auth to use. Options are 'ApiKey', 'SecurityToken' and 'InstancePrincipal' and
        'ResourcePrincipal'. By default, 'ApiKey' will be used.
        """
        return __config__.get('auth')

    @property
    def config_file_profile(self) -> Optional[str]:
        """
        (Optional) The profile name to be used from config file, if not set it will be DEFAULT.
        """
        return __config__.get('configFileProfile')

    @property
    def disable_auto_retries(self) -> Optional[bool]:
        """
        (Optional) Disable automatic retries for retriable errors. Automatic retries were introduced to solve some eventual
        consistency problems but it also introduced performance issues on destroy operations.
        """
        return __config__.get_bool('disableAutoRetries')

    @property
    def fingerprint(self) -> Optional[str]:
        """
        (Optional) The fingerprint for the user's RSA key. This can be found in user settings in the Oracle Cloud Infrastructure
        console. Required if auth is set to 'ApiKey', ignored otherwise.
        """
        return __config__.get('fingerprint')

    @property
    def ignore_defined_tags(self) -> Optional[str]:
        """
        (Optional) List of defined tags keys that Terraform should ignore when planning creates and updates to the associated
        remote object
        """
        return __config__.get('ignoreDefinedTags')

    @property
    def private_key(self) -> Optional[str]:
        """
        (Optional) A PEM formatted RSA private key for the user. A private_key or a private_key_path must be provided if auth is
        set to 'ApiKey', ignored otherwise.
        """
        return __config__.get('privateKey')

    @property
    def private_key_password(self) -> Optional[str]:
        """
        (Optional) The password used to secure the private key.
        """
        return __config__.get('privateKeyPassword')

    @property
    def private_key_path(self) -> Optional[str]:
        """
        (Optional) The path to the user's PEM formatted private key. A private_key or a private_key_path must be provided if
        auth is set to 'ApiKey', ignored otherwise.
        """
        return __config__.get('privateKeyPath')

    @property
    def region(self) -> Optional[str]:
        """
        (Required) The region for API connections (e.g. us-ashburn-1).
        """
        return __config__.get('region')

    @property
    def retry_duration_seconds(self) -> Optional[int]:
        """
        (Optional) The minimum duration (in seconds) to retry a resource operation in response to an error. The actual retry
        duration may be longer due to jittering of retry operations. This value is ignored if the `disable_auto_retries` field
        is set to true.
        """
        return __config__.get_int('retryDurationSeconds')

    @property
    def tenancy_ocid(self) -> Optional[str]:
        """
        (Optional) The tenancy OCID for a user. The tenancy OCID can be found at the bottom of user settings in the Oracle Cloud
        Infrastructure console. Required if auth is set to 'ApiKey', ignored otherwise.
        """
        return __config__.get('tenancyOcid')

    @property
    def user_ocid(self) -> Optional[str]:
        """
        (Optional) The user OCID. This can be found in user settings in the Oracle Cloud Infrastructure console. Required if
        auth is set to 'ApiKey', ignored otherwise.
        """
        return __config__.get('userOcid')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BuildRunArgs', 'BuildRun']

@pulumi.input_type
class BuildRunArgs:
    def __init__(__self__, *,
                 build_pipeline_id: pulumi.Input[str],
                 build_run_arguments: Optional[pulumi.Input['BuildRunBuildRunArgumentsArgs']] = None,
                 commit_info: Optional[pulumi.Input['BuildRunCommitInfoArgs']] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a BuildRun resource.
        :param pulumi.Input[str] build_pipeline_id: The OCID of the build pipeline.
        :param pulumi.Input['BuildRunBuildRunArgumentsArgs'] build_run_arguments: Specifies list of arguments passed along with the build run.
        :param pulumi.Input['BuildRunCommitInfoArgs'] commit_info: Commit details that need to be used for the build run.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "build_pipeline_id", build_pipeline_id)
        if build_run_arguments is not None:
            pulumi.set(__self__, "build_run_arguments", build_run_arguments)
        if commit_info is not None:
            pulumi.set(__self__, "commit_info", commit_info)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)

    @property
    @pulumi.getter(name="buildPipelineId")
    def build_pipeline_id(self) -> pulumi.Input[str]:
        """
        The OCID of the build pipeline.
        """
        return pulumi.get(self, "build_pipeline_id")

    @build_pipeline_id.setter
    def build_pipeline_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "build_pipeline_id", value)

    @property
    @pulumi.getter(name="buildRunArguments")
    def build_run_arguments(self) -> Optional[pulumi.Input['BuildRunBuildRunArgumentsArgs']]:
        """
        Specifies list of arguments passed along with the build run.
        """
        return pulumi.get(self, "build_run_arguments")

    @build_run_arguments.setter
    def build_run_arguments(self, value: Optional[pulumi.Input['BuildRunBuildRunArgumentsArgs']]):
        pulumi.set(self, "build_run_arguments", value)

    @property
    @pulumi.getter(name="commitInfo")
    def commit_info(self) -> Optional[pulumi.Input['BuildRunCommitInfoArgs']]:
        """
        Commit details that need to be used for the build run.
        """
        return pulumi.get(self, "commit_info")

    @commit_info.setter
    def commit_info(self, value: Optional[pulumi.Input['BuildRunCommitInfoArgs']]):
        pulumi.set(self, "commit_info", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)


@pulumi.input_type
class _BuildRunState:
    def __init__(__self__, *,
                 build_outputs: Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildOutputArgs']]]] = None,
                 build_pipeline_id: Optional[pulumi.Input[str]] = None,
                 build_run_arguments: Optional[pulumi.Input['BuildRunBuildRunArgumentsArgs']] = None,
                 build_run_progresses: Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunProgressArgs']]]] = None,
                 build_run_sources: Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunSourceArgs']]]] = None,
                 commit_info: Optional[pulumi.Input['BuildRunCommitInfoArgs']] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BuildRun resources.
        :param pulumi.Input[Sequence[pulumi.Input['BuildRunBuildOutputArgs']]] build_outputs: Outputs from the build.
        :param pulumi.Input[str] build_pipeline_id: The OCID of the build pipeline.
        :param pulumi.Input['BuildRunBuildRunArgumentsArgs'] build_run_arguments: Specifies list of arguments passed along with the build run.
        :param pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunProgressArgs']]] build_run_progresses: The run progress details of a build run.
        :param pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunSourceArgs']]] build_run_sources: The source from which the build run is triggered.
        :param pulumi.Input['BuildRunCommitInfoArgs'] commit_info: Commit details that need to be used for the build run.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment where the build is running.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] project_id: The OCID of the DevOps project.
        :param pulumi.Input[str] state: The current state of the build run.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] time_created: The time the build run was created. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        :param pulumi.Input[str] time_updated: The time the build run was updated. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        if build_outputs is not None:
            pulumi.set(__self__, "build_outputs", build_outputs)
        if build_pipeline_id is not None:
            pulumi.set(__self__, "build_pipeline_id", build_pipeline_id)
        if build_run_arguments is not None:
            pulumi.set(__self__, "build_run_arguments", build_run_arguments)
        if build_run_progresses is not None:
            pulumi.set(__self__, "build_run_progresses", build_run_progresses)
        if build_run_sources is not None:
            pulumi.set(__self__, "build_run_sources", build_run_sources)
        if commit_info is not None:
            pulumi.set(__self__, "commit_info", commit_info)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="buildOutputs")
    def build_outputs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildOutputArgs']]]]:
        """
        Outputs from the build.
        """
        return pulumi.get(self, "build_outputs")

    @build_outputs.setter
    def build_outputs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildOutputArgs']]]]):
        pulumi.set(self, "build_outputs", value)

    @property
    @pulumi.getter(name="buildPipelineId")
    def build_pipeline_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the build pipeline.
        """
        return pulumi.get(self, "build_pipeline_id")

    @build_pipeline_id.setter
    def build_pipeline_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "build_pipeline_id", value)

    @property
    @pulumi.getter(name="buildRunArguments")
    def build_run_arguments(self) -> Optional[pulumi.Input['BuildRunBuildRunArgumentsArgs']]:
        """
        Specifies list of arguments passed along with the build run.
        """
        return pulumi.get(self, "build_run_arguments")

    @build_run_arguments.setter
    def build_run_arguments(self, value: Optional[pulumi.Input['BuildRunBuildRunArgumentsArgs']]):
        pulumi.set(self, "build_run_arguments", value)

    @property
    @pulumi.getter(name="buildRunProgresses")
    def build_run_progresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunProgressArgs']]]]:
        """
        The run progress details of a build run.
        """
        return pulumi.get(self, "build_run_progresses")

    @build_run_progresses.setter
    def build_run_progresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunProgressArgs']]]]):
        pulumi.set(self, "build_run_progresses", value)

    @property
    @pulumi.getter(name="buildRunSources")
    def build_run_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunSourceArgs']]]]:
        """
        The source from which the build run is triggered.
        """
        return pulumi.get(self, "build_run_sources")

    @build_run_sources.setter
    def build_run_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BuildRunBuildRunSourceArgs']]]]):
        pulumi.set(self, "build_run_sources", value)

    @property
    @pulumi.getter(name="commitInfo")
    def commit_info(self) -> Optional[pulumi.Input['BuildRunCommitInfoArgs']]:
        """
        Commit details that need to be used for the build run.
        """
        return pulumi.get(self, "commit_info")

    @commit_info.setter
    def commit_info(self, value: Optional[pulumi.Input['BuildRunCommitInfoArgs']]):
        pulumi.set(self, "commit_info", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the compartment where the build is running.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the DevOps project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the build run.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time the build run was created. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time the build run was updated. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class BuildRun(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 build_pipeline_id: Optional[pulumi.Input[str]] = None,
                 build_run_arguments: Optional[pulumi.Input[pulumi.InputType['BuildRunBuildRunArgumentsArgs']]] = None,
                 commit_info: Optional[pulumi.Input[pulumi.InputType['BuildRunCommitInfoArgs']]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        """
        This resource provides the Build Run resource in Oracle Cloud Infrastructure Devops service.

        Starts a build pipeline run for a predefined build pipeline. Please ensure the completion of any work request for creation/updation of Build Pipeline before starting a Build Run.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_build_run = oci.dev_ops.BuildRun("testBuildRun",
            build_pipeline_id=oci_devops_build_pipeline["test_build_pipeline"]["id"],
            build_run_arguments=oci.dev_ops.BuildRunBuildRunArgumentsArgs(
                items=[oci.dev_ops.BuildRunBuildRunArgumentsItemArgs(
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            ),
            commit_info=oci.dev_ops.BuildRunCommitInfoArgs(
                commit_hash=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                repository_branch=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                repository_url=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            display_name=var["build_run_display_name"],
            freeform_tags={
                "bar-key": "value",
            })
        ```

        ## Import

        BuildRuns can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DevOps/buildRun:BuildRun test_build_run "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] build_pipeline_id: The OCID of the build pipeline.
        :param pulumi.Input[pulumi.InputType['BuildRunBuildRunArgumentsArgs']] build_run_arguments: Specifies list of arguments passed along with the build run.
        :param pulumi.Input[pulumi.InputType['BuildRunCommitInfoArgs']] commit_info: Commit details that need to be used for the build run.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BuildRunArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Build Run resource in Oracle Cloud Infrastructure Devops service.

        Starts a build pipeline run for a predefined build pipeline. Please ensure the completion of any work request for creation/updation of Build Pipeline before starting a Build Run.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_build_run = oci.dev_ops.BuildRun("testBuildRun",
            build_pipeline_id=oci_devops_build_pipeline["test_build_pipeline"]["id"],
            build_run_arguments=oci.dev_ops.BuildRunBuildRunArgumentsArgs(
                items=[oci.dev_ops.BuildRunBuildRunArgumentsItemArgs(
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            ),
            commit_info=oci.dev_ops.BuildRunCommitInfoArgs(
                commit_hash=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                repository_branch=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                repository_url=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            display_name=var["build_run_display_name"],
            freeform_tags={
                "bar-key": "value",
            })
        ```

        ## Import

        BuildRuns can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DevOps/buildRun:BuildRun test_build_run "id"
        ```

        :param str resource_name: The name of the resource.
        :param BuildRunArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BuildRunArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 build_pipeline_id: Optional[pulumi.Input[str]] = None,
                 build_run_arguments: Optional[pulumi.Input[pulumi.InputType['BuildRunBuildRunArgumentsArgs']]] = None,
                 commit_info: Optional[pulumi.Input[pulumi.InputType['BuildRunCommitInfoArgs']]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BuildRunArgs.__new__(BuildRunArgs)

            if build_pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'build_pipeline_id'")
            __props__.__dict__["build_pipeline_id"] = build_pipeline_id
            __props__.__dict__["build_run_arguments"] = build_run_arguments
            __props__.__dict__["commit_info"] = commit_info
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["build_outputs"] = None
            __props__.__dict__["build_run_progresses"] = None
            __props__.__dict__["build_run_sources"] = None
            __props__.__dict__["compartment_id"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        super(BuildRun, __self__).__init__(
            'oci:DevOps/buildRun:BuildRun',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            build_outputs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BuildRunBuildOutputArgs']]]]] = None,
            build_pipeline_id: Optional[pulumi.Input[str]] = None,
            build_run_arguments: Optional[pulumi.Input[pulumi.InputType['BuildRunBuildRunArgumentsArgs']]] = None,
            build_run_progresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BuildRunBuildRunProgressArgs']]]]] = None,
            build_run_sources: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BuildRunBuildRunSourceArgs']]]]] = None,
            commit_info: Optional[pulumi.Input[pulumi.InputType['BuildRunCommitInfoArgs']]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'BuildRun':
        """
        Get an existing BuildRun resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BuildRunBuildOutputArgs']]]] build_outputs: Outputs from the build.
        :param pulumi.Input[str] build_pipeline_id: The OCID of the build pipeline.
        :param pulumi.Input[pulumi.InputType['BuildRunBuildRunArgumentsArgs']] build_run_arguments: Specifies list of arguments passed along with the build run.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BuildRunBuildRunProgressArgs']]]] build_run_progresses: The run progress details of a build run.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BuildRunBuildRunSourceArgs']]]] build_run_sources: The source from which the build run is triggered.
        :param pulumi.Input[pulumi.InputType['BuildRunCommitInfoArgs']] commit_info: Commit details that need to be used for the build run.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment where the build is running.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] project_id: The OCID of the DevOps project.
        :param pulumi.Input[str] state: The current state of the build run.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] time_created: The time the build run was created. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        :param pulumi.Input[str] time_updated: The time the build run was updated. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BuildRunState.__new__(_BuildRunState)

        __props__.__dict__["build_outputs"] = build_outputs
        __props__.__dict__["build_pipeline_id"] = build_pipeline_id
        __props__.__dict__["build_run_arguments"] = build_run_arguments
        __props__.__dict__["build_run_progresses"] = build_run_progresses
        __props__.__dict__["build_run_sources"] = build_run_sources
        __props__.__dict__["commit_info"] = commit_info
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["state"] = state
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        return BuildRun(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="buildOutputs")
    def build_outputs(self) -> pulumi.Output[Sequence['outputs.BuildRunBuildOutput']]:
        """
        Outputs from the build.
        """
        return pulumi.get(self, "build_outputs")

    @property
    @pulumi.getter(name="buildPipelineId")
    def build_pipeline_id(self) -> pulumi.Output[str]:
        """
        The OCID of the build pipeline.
        """
        return pulumi.get(self, "build_pipeline_id")

    @property
    @pulumi.getter(name="buildRunArguments")
    def build_run_arguments(self) -> pulumi.Output['outputs.BuildRunBuildRunArguments']:
        """
        Specifies list of arguments passed along with the build run.
        """
        return pulumi.get(self, "build_run_arguments")

    @property
    @pulumi.getter(name="buildRunProgresses")
    def build_run_progresses(self) -> pulumi.Output[Sequence['outputs.BuildRunBuildRunProgress']]:
        """
        The run progress details of a build run.
        """
        return pulumi.get(self, "build_run_progresses")

    @property
    @pulumi.getter(name="buildRunSources")
    def build_run_sources(self) -> pulumi.Output[Sequence['outputs.BuildRunBuildRunSource']]:
        """
        The source from which the build run is triggered.
        """
        return pulumi.get(self, "build_run_sources")

    @property
    @pulumi.getter(name="commitInfo")
    def commit_info(self) -> pulumi.Output['outputs.BuildRunCommitInfo']:
        """
        Commit details that need to be used for the build run.
        """
        return pulumi.get(self, "commit_info")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the compartment where the build is running.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The OCID of the DevOps project.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the build run.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time the build run was created. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time the build run was updated. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        return pulumi.get(self, "time_updated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSuppressionsResult',
    'AwaitableGetSuppressionsResult',
    'get_suppressions',
    'get_suppressions_output',
]

@pulumi.output_type
class GetSuppressionsResult:
    """
    A collection of values returned by getSuppressions.
    """
    def __init__(__self__, compartment_id=None, email_address=None, filters=None, id=None, suppressions=None, time_created_greater_than_or_equal_to=None, time_created_less_than=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if email_address and not isinstance(email_address, str):
            raise TypeError("Expected argument 'email_address' to be a str")
        pulumi.set(__self__, "email_address", email_address)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if suppressions and not isinstance(suppressions, list):
            raise TypeError("Expected argument 'suppressions' to be a list")
        pulumi.set(__self__, "suppressions", suppressions)
        if time_created_greater_than_or_equal_to and not isinstance(time_created_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'time_created_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "time_created_greater_than_or_equal_to", time_created_greater_than_or_equal_to)
        if time_created_less_than and not isinstance(time_created_less_than, str):
            raise TypeError("Expected argument 'time_created_less_than' to be a str")
        pulumi.set(__self__, "time_created_less_than", time_created_less_than)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment to contain the suppression. Since suppressions are at the customer level, this must be the tenancy OCID.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="emailAddress")
    def email_address(self) -> Optional[str]:
        """
        The email address of the suppression.
        """
        return pulumi.get(self, "email_address")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetSuppressionsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def suppressions(self) -> Sequence['outputs.GetSuppressionsSuppressionResult']:
        """
        The list of suppressions.
        """
        return pulumi.get(self, "suppressions")

    @property
    @pulumi.getter(name="timeCreatedGreaterThanOrEqualTo")
    def time_created_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "time_created_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timeCreatedLessThan")
    def time_created_less_than(self) -> Optional[str]:
        return pulumi.get(self, "time_created_less_than")


class AwaitableGetSuppressionsResult(GetSuppressionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSuppressionsResult(
            compartment_id=self.compartment_id,
            email_address=self.email_address,
            filters=self.filters,
            id=self.id,
            suppressions=self.suppressions,
            time_created_greater_than_or_equal_to=self.time_created_greater_than_or_equal_to,
            time_created_less_than=self.time_created_less_than)


def get_suppressions(compartment_id: Optional[str] = None,
                     email_address: Optional[str] = None,
                     filters: Optional[Sequence[pulumi.InputType['GetSuppressionsFilterArgs']]] = None,
                     time_created_greater_than_or_equal_to: Optional[str] = None,
                     time_created_less_than: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSuppressionsResult:
    """
    This data source provides the list of Suppressions in Oracle Cloud Infrastructure Email service.

    Gets a list of suppressed recipient email addresses for a user. The
    `compartmentId` for suppressions must be a tenancy OCID. The returned list
    is sorted by creation time in descending order.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_suppressions = oci.Email.get_suppressions(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        email_address=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_created_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_created_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID for the compartment.
    :param str email_address: The email address of the suppression.
    :param str time_created_greater_than_or_equal_to: Search for suppressions that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve suppressions created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_created_less_than: Search for suppressions that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all suppressions created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
           
           **Example:** 2016-12-19T16:39:57.600Z
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['emailAddress'] = email_address
    __args__['filters'] = filters
    __args__['timeCreatedGreaterThanOrEqualTo'] = time_created_greater_than_or_equal_to
    __args__['timeCreatedLessThan'] = time_created_less_than
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Email/getSuppressions:getSuppressions', __args__, opts=opts, typ=GetSuppressionsResult).value

    return AwaitableGetSuppressionsResult(
        compartment_id=__ret__.compartment_id,
        email_address=__ret__.email_address,
        filters=__ret__.filters,
        id=__ret__.id,
        suppressions=__ret__.suppressions,
        time_created_greater_than_or_equal_to=__ret__.time_created_greater_than_or_equal_to,
        time_created_less_than=__ret__.time_created_less_than)


@_utilities.lift_output_func(get_suppressions)
def get_suppressions_output(compartment_id: Optional[pulumi.Input[str]] = None,
                            email_address: Optional[pulumi.Input[Optional[str]]] = None,
                            filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetSuppressionsFilterArgs']]]]] = None,
                            time_created_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                            time_created_less_than: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSuppressionsResult]:
    """
    This data source provides the list of Suppressions in Oracle Cloud Infrastructure Email service.

    Gets a list of suppressed recipient email addresses for a user. The
    `compartmentId` for suppressions must be a tenancy OCID. The returned list
    is sorted by creation time in descending order.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_suppressions = oci.Email.get_suppressions(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        email_address=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_created_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_created_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID for the compartment.
    :param str email_address: The email address of the suppression.
    :param str time_created_greater_than_or_equal_to: Search for suppressions that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve suppressions created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_created_less_than: Search for suppressions that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all suppressions created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
           
           **Example:** 2016-12-19T16:39:57.600Z
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFusionEnvironmentAdminUsersResult',
    'AwaitableGetFusionEnvironmentAdminUsersResult',
    'get_fusion_environment_admin_users',
    'get_fusion_environment_admin_users_output',
]

@pulumi.output_type
class GetFusionEnvironmentAdminUsersResult:
    """
    A collection of values returned by getFusionEnvironmentAdminUsers.
    """
    def __init__(__self__, admin_user_collections=None, filters=None, fusion_environment_id=None, id=None):
        if admin_user_collections and not isinstance(admin_user_collections, list):
            raise TypeError("Expected argument 'admin_user_collections' to be a list")
        pulumi.set(__self__, "admin_user_collections", admin_user_collections)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if fusion_environment_id and not isinstance(fusion_environment_id, str):
            raise TypeError("Expected argument 'fusion_environment_id' to be a str")
        pulumi.set(__self__, "fusion_environment_id", fusion_environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="adminUserCollections")
    def admin_user_collections(self) -> Sequence['outputs.GetFusionEnvironmentAdminUsersAdminUserCollectionResult']:
        """
        The list of admin_user_collection.
        """
        return pulumi.get(self, "admin_user_collections")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetFusionEnvironmentAdminUsersFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="fusionEnvironmentId")
    def fusion_environment_id(self) -> str:
        return pulumi.get(self, "fusion_environment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetFusionEnvironmentAdminUsersResult(GetFusionEnvironmentAdminUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFusionEnvironmentAdminUsersResult(
            admin_user_collections=self.admin_user_collections,
            filters=self.filters,
            fusion_environment_id=self.fusion_environment_id,
            id=self.id)


def get_fusion_environment_admin_users(filters: Optional[Sequence[pulumi.InputType['GetFusionEnvironmentAdminUsersFilterArgs']]] = None,
                                       fusion_environment_id: Optional[str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFusionEnvironmentAdminUsersResult:
    """
    This data source provides the list of Fusion Environment Admin Users in Oracle Cloud Infrastructure Fusion Apps service.

    List all FusionEnvironment admin users

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_admin_users = oci.Functions.get_fusion_environment_admin_users(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['fusionEnvironmentId'] = fusion_environment_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Functions/getFusionEnvironmentAdminUsers:getFusionEnvironmentAdminUsers', __args__, opts=opts, typ=GetFusionEnvironmentAdminUsersResult).value

    return AwaitableGetFusionEnvironmentAdminUsersResult(
        admin_user_collections=__ret__.admin_user_collections,
        filters=__ret__.filters,
        fusion_environment_id=__ret__.fusion_environment_id,
        id=__ret__.id)


@_utilities.lift_output_func(get_fusion_environment_admin_users)
def get_fusion_environment_admin_users_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetFusionEnvironmentAdminUsersFilterArgs']]]]] = None,
                                              fusion_environment_id: Optional[pulumi.Input[str]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFusionEnvironmentAdminUsersResult]:
    """
    This data source provides the list of Fusion Environment Admin Users in Oracle Cloud Infrastructure Fusion Apps service.

    List all FusionEnvironment admin users

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_admin_users = oci.Functions.get_fusion_environment_admin_users(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['AgentDependencyArgs', 'AgentDependency']

@pulumi.input_type
class AgentDependencyArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str],
                 compartment_id: pulumi.Input[str],
                 dependency_name: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 namespace: pulumi.Input[str],
                 object: pulumi.Input[str],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 dependency_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a AgentDependency resource.
        :param pulumi.Input[str] bucket: (Updatable) Object storage bucket where the dependency is uploaded.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[str] dependency_name: (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        :param pulumi.Input[str] display_name: (Updatable) Display name of the Agent dependency.
        :param pulumi.Input[str] namespace: (Updatable) Object storage namespace associated with the customer's tenancy.
        :param pulumi.Input[str] object: (Updatable) Name of the dependency object uploaded by the customer.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] dependency_version: (Updatable) Version of the Agent dependency.
        :param pulumi.Input[str] description: (Updatable) Description about the Agent dependency.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[Mapping[str, Any]] system_tags: (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "dependency_name", dependency_name)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "object", object)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if dependency_version is not None:
            pulumi.set(__self__, "dependency_version", dependency_version)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        (Updatable) Object storage bucket where the dependency is uploaded.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) Compartment identifier.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="dependencyName")
    def dependency_name(self) -> pulumi.Input[str]:
        """
        (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        """
        return pulumi.get(self, "dependency_name")

    @dependency_name.setter
    def dependency_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "dependency_name", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        (Updatable) Display name of the Agent dependency.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        (Updatable) Object storage namespace associated with the customer's tenancy.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def object(self) -> pulumi.Input[str]:
        """
        (Updatable) Name of the dependency object uploaded by the customer.
        """
        return pulumi.get(self, "object")

    @object.setter
    def object(self, value: pulumi.Input[str]):
        pulumi.set(self, "object", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="dependencyVersion")
    def dependency_version(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Version of the Agent dependency.
        """
        return pulumi.get(self, "dependency_version")

    @dependency_version.setter
    def dependency_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dependency_version", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Description about the Agent dependency.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)


@pulumi.input_type
class _AgentDependencyState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[str]] = None,
                 checksum: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 dependency_name: Optional[pulumi.Input[str]] = None,
                 dependency_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 e_tag: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 object: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AgentDependency resources.
        :param pulumi.Input[str] bucket: (Updatable) Object storage bucket where the dependency is uploaded.
        :param pulumi.Input[str] checksum: The checksum associated with the dependency object returned by Object Storage.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] dependency_name: (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        :param pulumi.Input[str] dependency_version: (Updatable) Version of the Agent dependency.
        :param pulumi.Input[str] description: (Updatable) Description about the Agent dependency.
        :param pulumi.Input[str] display_name: (Updatable) Display name of the Agent dependency.
        :param pulumi.Input[str] e_tag: The eTag associated with the dependency object returned by Object Storage.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] namespace: (Updatable) Object storage namespace associated with the customer's tenancy.
        :param pulumi.Input[str] object: (Updatable) Name of the dependency object uploaded by the customer.
        :param pulumi.Input[str] state: The current state of AgentDependency.
        :param pulumi.Input[Mapping[str, Any]] system_tags: (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_created: The time when the AgentDependency was created. An RFC3339 formatted datetime string.
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if checksum is not None:
            pulumi.set(__self__, "checksum", checksum)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if dependency_name is not None:
            pulumi.set(__self__, "dependency_name", dependency_name)
        if dependency_version is not None:
            pulumi.set(__self__, "dependency_version", dependency_version)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if e_tag is not None:
            pulumi.set(__self__, "e_tag", e_tag)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if object is not None:
            pulumi.set(__self__, "object", object)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Object storage bucket where the dependency is uploaded.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def checksum(self) -> Optional[pulumi.Input[str]]:
        """
        The checksum associated with the dependency object returned by Object Storage.
        """
        return pulumi.get(self, "checksum")

    @checksum.setter
    def checksum(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "checksum", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Compartment identifier.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="dependencyName")
    def dependency_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        """
        return pulumi.get(self, "dependency_name")

    @dependency_name.setter
    def dependency_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dependency_name", value)

    @property
    @pulumi.getter(name="dependencyVersion")
    def dependency_version(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Version of the Agent dependency.
        """
        return pulumi.get(self, "dependency_version")

    @dependency_version.setter
    def dependency_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dependency_version", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Description about the Agent dependency.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Display name of the Agent dependency.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="eTag")
    def e_tag(self) -> Optional[pulumi.Input[str]]:
        """
        The eTag associated with the dependency object returned by Object Storage.
        """
        return pulumi.get(self, "e_tag")

    @e_tag.setter
    def e_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "e_tag", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Object storage namespace associated with the customer's tenancy.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def object(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name of the dependency object uploaded by the customer.
        """
        return pulumi.get(self, "object")

    @object.setter
    def object(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "object", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of AgentDependency.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the AgentDependency was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)


class AgentDependency(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 dependency_name: Optional[pulumi.Input[str]] = None,
                 dependency_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 object: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        """
        This resource provides the Agent Dependency resource in Oracle Cloud Infrastructure Cloud Bridge service.

        Creates an AgentDependency.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_agent_dependency = oci.cloud_bridge.AgentDependency("testAgentDependency",
            bucket=var["agent_dependency_bucket"],
            compartment_id=var["compartment_id"],
            dependency_name=var["agent_dependency_dependency_name"],
            display_name=var["agent_dependency_display_name"],
            namespace=var["agent_dependency_namespace"],
            object=var["agent_dependency_object"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            dependency_version=var["agent_dependency_dependency_version"],
            description=var["agent_dependency_description"],
            freeform_tags={
                "Department": "Finance",
            },
            system_tags=var["agent_dependency_system_tags"])
        ```

        ## Import

        AgentDependencies can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CloudBridge/agentDependency:AgentDependency test_agent_dependency "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: (Updatable) Object storage bucket where the dependency is uploaded.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] dependency_name: (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        :param pulumi.Input[str] dependency_version: (Updatable) Version of the Agent dependency.
        :param pulumi.Input[str] description: (Updatable) Description about the Agent dependency.
        :param pulumi.Input[str] display_name: (Updatable) Display name of the Agent dependency.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] namespace: (Updatable) Object storage namespace associated with the customer's tenancy.
        :param pulumi.Input[str] object: (Updatable) Name of the dependency object uploaded by the customer.
        :param pulumi.Input[Mapping[str, Any]] system_tags: (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AgentDependencyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Agent Dependency resource in Oracle Cloud Infrastructure Cloud Bridge service.

        Creates an AgentDependency.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_agent_dependency = oci.cloud_bridge.AgentDependency("testAgentDependency",
            bucket=var["agent_dependency_bucket"],
            compartment_id=var["compartment_id"],
            dependency_name=var["agent_dependency_dependency_name"],
            display_name=var["agent_dependency_display_name"],
            namespace=var["agent_dependency_namespace"],
            object=var["agent_dependency_object"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            dependency_version=var["agent_dependency_dependency_version"],
            description=var["agent_dependency_description"],
            freeform_tags={
                "Department": "Finance",
            },
            system_tags=var["agent_dependency_system_tags"])
        ```

        ## Import

        AgentDependencies can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CloudBridge/agentDependency:AgentDependency test_agent_dependency "id"
        ```

        :param str resource_name: The name of the resource.
        :param AgentDependencyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AgentDependencyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 dependency_name: Optional[pulumi.Input[str]] = None,
                 dependency_version: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 object: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AgentDependencyArgs.__new__(AgentDependencyArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            if dependency_name is None and not opts.urn:
                raise TypeError("Missing required property 'dependency_name'")
            __props__.__dict__["dependency_name"] = dependency_name
            __props__.__dict__["dependency_version"] = dependency_version
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            if object is None and not opts.urn:
                raise TypeError("Missing required property 'object'")
            __props__.__dict__["object"] = object
            __props__.__dict__["system_tags"] = system_tags
            __props__.__dict__["checksum"] = None
            __props__.__dict__["e_tag"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
        super(AgentDependency, __self__).__init__(
            'oci:CloudBridge/agentDependency:AgentDependency',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[str]] = None,
            checksum: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            dependency_name: Optional[pulumi.Input[str]] = None,
            dependency_version: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            e_tag: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            object: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            time_created: Optional[pulumi.Input[str]] = None) -> 'AgentDependency':
        """
        Get an existing AgentDependency resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: (Updatable) Object storage bucket where the dependency is uploaded.
        :param pulumi.Input[str] checksum: The checksum associated with the dependency object returned by Object Storage.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] dependency_name: (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        :param pulumi.Input[str] dependency_version: (Updatable) Version of the Agent dependency.
        :param pulumi.Input[str] description: (Updatable) Description about the Agent dependency.
        :param pulumi.Input[str] display_name: (Updatable) Display name of the Agent dependency.
        :param pulumi.Input[str] e_tag: The eTag associated with the dependency object returned by Object Storage.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] namespace: (Updatable) Object storage namespace associated with the customer's tenancy.
        :param pulumi.Input[str] object: (Updatable) Name of the dependency object uploaded by the customer.
        :param pulumi.Input[str] state: The current state of AgentDependency.
        :param pulumi.Input[Mapping[str, Any]] system_tags: (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_created: The time when the AgentDependency was created. An RFC3339 formatted datetime string.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AgentDependencyState.__new__(_AgentDependencyState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["checksum"] = checksum
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["dependency_name"] = dependency_name
        __props__.__dict__["dependency_version"] = dependency_version
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["e_tag"] = e_tag
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["object"] = object
        __props__.__dict__["state"] = state
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["time_created"] = time_created
        return AgentDependency(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[str]:
        """
        (Updatable) Object storage bucket where the dependency is uploaded.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def checksum(self) -> pulumi.Output[str]:
        """
        The checksum associated with the dependency object returned by Object Storage.
        """
        return pulumi.get(self, "checksum")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) Compartment identifier.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="dependencyName")
    def dependency_name(self) -> pulumi.Output[str]:
        """
        (Updatable) Name of the dependency type. This should match the whitelisted enum of dependency names.
        """
        return pulumi.get(self, "dependency_name")

    @property
    @pulumi.getter(name="dependencyVersion")
    def dependency_version(self) -> pulumi.Output[str]:
        """
        (Updatable) Version of the Agent dependency.
        """
        return pulumi.get(self, "dependency_version")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) Description about the Agent dependency.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) Display name of the Agent dependency.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="eTag")
    def e_tag(self) -> pulumi.Output[str]:
        """
        The eTag associated with the dependency object returned by Object Storage.
        """
        return pulumi.get(self, "e_tag")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        (Updatable) Object storage namespace associated with the customer's tenancy.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def object(self) -> pulumi.Output[str]:
        """
        (Updatable) Name of the dependency object uploaded by the customer.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of AgentDependency.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}` 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time when the AgentDependency was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

